@@ -2,8 +2,6 @@
 #
 # Copyright © 2014 eNovance
 #
-# Author: Julien Danjou <julien@danjou.info>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -33,8 +31,12 @@ RETRYING_KWARGS = dict(
 )
 
 
-def retry(f):
-    return retrying.retry(**RETRYING_KWARGS)(f)
+def retry(**kwargs):
+    def _retry(f):
+        k = RETRYING_KWARGS.copy()
+        k.update(kwargs)
+        return retrying.retry(**k)(f)
+    return _retry
 
 
 Retrying = retrying.Retrying
